@@ -19,7 +19,9 @@
 ;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 ;; Boston, MA 02111-1307, USA.
 
-;; Code
+;;; Commentary:
+
+;;; Code:
 
 (provide 'viper-init)
 
@@ -492,7 +494,7 @@ text."
 (defcustom viper-fast-keyseq-timeout 200
   "*Key sequence separated by no more than this many milliseconds is viewed as a Vi-style macro, if such a macro is defined.
 Setting this too high may slow down your typing.  Setting this value too low
-will make it hard to use Vi-stile timeout macros."
+will make it hard to use Vi-style timeout macros."
   :type 'integer
   :group 'viper-misc)
 
@@ -510,7 +512,7 @@ on a dumb terminal."
 Normally, Viper lets Emacs translate only those ESC key sequences that are
 defined in the low-level key-translation-map or function-key-map, such as those
 emitted by the arrow and function keys. Other sequences, e.g., \\e/, are
-treated as ESQ command followed by a `/'. This is done for people who type fast
+treated as ESC command followed by a `/'. This is done for people who type fast
 and tend to hit other characters right after they hit ESC. Other people like
 Emacs to translate ESC sequences all the time. 
 The default is to translate all sequences only when using a dumb terminal.
@@ -986,4 +988,4 @@ Should be set in `~/.viper' file."
 ;;; eval: (put 'viper-deflocalvar 'lisp-indent-hook 'defun)
 ;;; End:
 
-;;;  viper-ex.el ends here
+;;; viper-init.el ends here
